#include <glib.h>
#include <glib/gstdio.h>
#include "unity-webapps-dpkg-available-application.h"
#include "unity-webapps-local-available-application.h"
#include "unity-webapps-policy-authorizer.h"
#include "unity-webapps-application-repository.h"
#include "unity-webapps-script-loader.h"
#include "unity-webapps-debug.h"

static GMainLoop *main_loop = NULL;

static void
print_userscript_contents (UnityWebappsApplicationRepository *repository, const gchar *app)
{
  gchar *contents;

  contents = unity_webapps_application_repository_get_userscript_contents (repository, app);
  g_printf("Userscript contents: %s \n", contents);
  g_free (contents);
}

static void
install_response (UnityWebappsApplicationRepository *repository,
		  const gchar *name,
		  UnityWebappsApplicationStatus status,
		  gpointer user_data)
{
  g_printf ("Found application: %s \n", name);
  
  switch (status)
    {
    case UNITY_WEBAPPS_APPLICATION_STATUS_AVAILABLE:
      g_printf("Application available for install \n");
      break;
    case UNITY_WEBAPPS_APPLICATION_STATUS_INSTALLED:
      g_printf("Application installed \n");
      print_userscript_contents (repository, name);
      break;
    default:
      g_assert_not_reached ();
    }
}

int
main (int argc, gchar **argv)
{
  UnityWebappsApplicationRepository *repository;
  const gchar *name;
  UnityWebappsApplicationStatus status;

  g_type_init ();

  unity_webapps_debug_initialize_flags ();
  
  repository = unity_webapps_application_repository_new_default ();
  unity_webapps_application_repository_prepare (repository);
  
  name = unity_webapps_application_repository_resolve_url (repository, argv[1]);
  
  status = unity_webapps_application_repository_get_resolved_application_status (repository, name);
  
  g_printf ("Found application: %s \n", name);
  
  switch (status)
    {
    case UNITY_WEBAPPS_APPLICATION_STATUS_AVAILABLE:
      g_printf("Application available for install \n");
      unity_webapps_application_repository_install_application (repository, name, install_response, NULL);
      break;
    case UNITY_WEBAPPS_APPLICATION_STATUS_INSTALLED:
      g_printf("Application installed \n");
      print_userscript_contents (repository, name);
      break;
    default:
      g_assert_not_reached ();
    }
  
  main_loop = g_main_loop_new (NULL, FALSE);
  g_main_loop_run (main_loop);
  
  return 0;
}
